@@ -58,7 +58,7 @@
 #define BATTERY_PERCENTAGE_UNKNOWN  (-1)
 #endif
 
-#ifndef BATTERY_TIME_UKNOWN
+#ifndef BATTERY_TIME_UNKNOWN
 #define BATTERY_TIME_UNKNOWN        (-1)
 #endif
 
@@ -213,7 +213,7 @@ battfink_apm_animate_charging (BattfinkApm *battfink_apm)
 static gchar *
 battfink_apm_get_time (BattfinkApm *battfink_apm)
 { 
-  if (battfink_apm->priv->show_time) {
+  if (battfink_apm->priv->show_time && battfink_apm->priv->battery_time != BATTERY_TIME_UNKNOWN) {
     if (battfink_apm->priv->battery_time == 0)
       return g_strdup_printf ("");
     else {
@@ -293,7 +293,8 @@ battfink_apm_update_image (BattfinkApm *battfink_apm)
     g_error_free (error);
   }
 
-  if (battfink_apm->priv->battery_time != BATTERY_TIME_UNKNOWN)
+  if (battfink_apm->priv->battery_time != BATTERY_TIME_UNKNOWN || 
+      battfink_apm->priv->battery_percentage != BATTERY_PERCENTAGE_UNKNOWN)
     battfink_apm_update_label (battfink_apm);
 
   battfink_apm_update_tooltip (battfink_apm);
@@ -583,7 +584,8 @@ battfink_apm_popup_menu (BattfinkApm *battfink_apm, guint button, guint32 activa
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 
   if (battfink_apm->priv->battery_time > 0
-      && !(battfink_apm->priv->battery_flags & BATTERY_FLAGS_ABSENT)) {
+      && !(battfink_apm->priv->battery_flags & BATTERY_FLAGS_ABSENT)
+      && !battfink_apm->priv->battery_charging) {
     battfink_apm->priv->time_menu_item = gtk_radio_menu_item_new_with_mnemonic (battfink_apm->priv->menu_group, 
                                                                                 _("_Time Remaining"));
     battfink_apm->priv->menu_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (battfink_apm->priv->time_menu_item));
